==> haskell-transformers-base-0.4.6-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 transformers-base
version:              0.4.6
visibility:           public
id:                   transformers-base-0.4.6-Ad5ai8CclXRChFF7BTqxJZ
key:                  transformers-base-0.4.6-Ad5ai8CclXRChFF7BTqxJZ
license:              BSD-3-Clause
copyright:
    2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:
    Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
homepage:             https://github.com/mvv/transformers-base
synopsis:             Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.

category:             Control
abi:                  049f542c7151acbca66fd0a4de6409b9
exposed:              True
exposed-modules:      Control.Monad.Base
import-dirs:          /usr/lib/ghc-9.2.8/site-local/transformers-base-0.4.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/transformers-base-0.4.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-transformers-base
hs-libraries:         HStransformers-base-0.4.6-Ad5ai8CclXRChFF7BTqxJZ
depends:
    base-4.16.4.0 base-orphans-0.8.8.2-D0306NFnVRp1Ybrf5kULRD
    stm-2.5.0.2 transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:
    /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock

haddock-html:         /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-base-0.4.6-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 transformers-base
version:              0.4.6
visibility:           public
id:                   transformers-base-0.4.6-10tXe5MiLs4HsBLDXsNGWs
key:                  transformers-base-0.4.6-10tXe5MiLs4HsBLDXsNGWs
license:              BSD-3-Clause
copyright:
    2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:
    Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
homepage:             https://github.com/mvv/transformers-base
synopsis:             Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.

category:             Control
abi:                  628d0e953fde54715a60568e592c307f
exposed:              True
exposed-modules:      Control.Monad.Base
import-dirs:          /usr/lib/ghc-9.2.8/site-local/transformers-base-0.4.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/transformers-base-0.4.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-transformers-base
hs-libraries:         HStransformers-base-0.4.6-10tXe5MiLs4HsBLDXsNGWs
depends:
    base-4.16.4.0 base-orphans-0.8.8.2-75FlsKP5UVdIbLopNxxJmB
    stm-2.5.0.2 transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:
    /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock

haddock-html:         /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
